.. rst-class:: detail

FeedbackLevel
========================

.. currentmodule:: compas_rrc

.. autoclass:: FeedbackLevel

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~FeedbackLevel.__init__
    
    